@@ -11,12 +11,13 @@
 /*
  * Class:     org_rocksdb_CassandraCompactionFilter
  * Method:    createNewCassandraCompactionFilter0
- * Signature: ()J
+ * Signature: (ZI)J
  */
 jlong Java_org_rocksdb_CassandraCompactionFilter_createNewCassandraCompactionFilter0(
-    JNIEnv* env, jclass jcls, jboolean purge_ttl_on_expiration) {
-  auto* compaction_filter =
-      new rocksdb::cassandra::CassandraCompactionFilter(purge_ttl_on_expiration);
+    JNIEnv* env, jclass jcls, jboolean purge_ttl_on_expiration,
+    jint gc_grace_period_in_seconds) {
+  auto* compaction_filter = new rocksdb::cassandra::CassandraCompactionFilter(
+      purge_ttl_on_expiration, gc_grace_period_in_seconds);
   // set the native handle to our native compaction filter
   return reinterpret_cast<jlong>(compaction_filter);
 }
